
    ⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢀⡀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⢠⣿⣿⡄⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠀⠀⠀⣀⣤⣶⣧⣄⣉⣉⣠⣼⣶⣤⣀⠀⠀⠀⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠀⢰⣿⣿⣿⣿⡿⣿⣿⣿⣿⢿⣿⣿⣿⣿⡆⠀⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠀⣼⣤⣤⣈⠙⠳⢄⣉⣋⡡⠞⠋⣁⣤⣤⣧⠀⠀⠀⠀⠀⠀⠀
    ⠀⢲⣶⣤⣄⡀⢀⣿⣄⠙⠿⣿⣦⣤⡿⢿⣤⣴⣿⠿⠋⣠⣿⠀⢀⣠⣤⣶⡖⠀
    ⠀⠀⠙⣿⠛⠇⢸⣿⣿⡟⠀⡄⢉⠉⢀⡀⠉⡉⢠⠀⢻⣿⣿⡇⠸⠛⣿⠋⠀⠀
    ⠀⠀⠀⠘⣷⠀⢸⡏⠻⣿⣤⣤⠂⣠⣿⣿⣄⠑⣤⣤⣿⠟⢹⡇⠀⣾⠃⠀⠀⠀
    ⠀⠀⠀⠀⠘⠀⢸⣿⡀⢀⠙⠻⢦⣌⣉⣉⣡⡴⠟⠋⡀⢀⣿⡇⠀⠃⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⢸⣿⣧⠈⠛⠂⠀⠉⠛⠛⠉⠀⠐⠛⠁⣼⣿⡇⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠸⣏⠀⣤⡶⠖⠛⠋⠉⠉⠙⠛⠲⢶⣤⠀⣹⠇⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠀⠀⠀⢹⣿⣶⣿⣿⣿⣿⣿⣿⣶⣿⡏⠀⠀⠀⠀⠀⠀⠀⠀⠀
    ⠀⠀⠀⠀⠀⠀⠀⠀⠀⠈⠉⠉⠉⠛⠛⠛⠛⠉⠉⠉⠁⠀⠀⠀⠀⠀⠀⠀⠀⠀
## OrcBench: A Representative Serverless Benchmark
OrcBench generates a workload trace which can be consumed by serverless
platforms to test their service. The models used by OrcBench are modeled off of
Microsoft Azure and whos creation is outlined in our paper (referenced below).

### Installation
```
pip install orcbench
```

### Quick Start
```
orcbench trace
```
This will produce a standard trace (25% that of the original Microsoft
Workload, `--scale 0.25`). nd produces jobs which will sample for 10 models
(`--N 10`). With a runtime (`--runtime 30`) of 30 minutes. The seed (`--seed`)
can be optionally set to produce deterministic workloads. The outputted
(`--out`) trace is by default sent to `trace.out`. 

## Referencing Us 
If you use this benchmark please make sure to cite us using the following citation

PDF of the paper can be found - [OrcBench: A Representative Serverless Benchmark](https://rcs.uwaterloo.ca/~ryan/files/orcbench.pdf)

```
@inproceedings{hancock:benchmarking,
  author    = {Ryan Hancock and
               Sreeharsha Udayashankar and
               Ali José Mashtizadeh and
               Samer Al-Kiswany},
  title     = {OrcBench: A Representative Serverless Benchmark},
  booktitle = {Proceedings of the15th International Conference on Cloud Computing (CLOUD'22)}
  publisher = {{IEEE}},
  year      = {2022},
  doi       = {10.1109/CLOUD55607.2022.00028},
}
```

